@@ -22,9 +22,12 @@ import java.util.function.Supplier;
 import org.jboss.errai.common.client.dom.HTMLElement;
 import org.kie.workbench.common.dmn.api.definition.HasExpression;
 import org.kie.workbench.common.dmn.api.definition.HasName;
-import org.kie.workbench.common.dmn.api.definition.v1_1.Definitions;
+import org.kie.workbench.common.dmn.api.definition.model.DMNDiagramElement;
+import org.kie.workbench.common.dmn.api.definition.model.Definitions;
 import org.kie.workbench.common.dmn.api.property.dmn.Name;
-import org.kie.workbench.common.dmn.client.decision.DecisionNavigatorPresenter;
+import org.kie.workbench.common.dmn.client.docks.navigator.DecisionNavigatorPresenter;
+import org.kie.workbench.common.dmn.client.docks.navigator.drds.DMNDiagramsSession;
+import org.kie.workbench.common.dmn.client.editors.drd.DRDNameChanger;
 import org.kie.workbench.common.dmn.client.editors.toolbar.ToolbarStateHandler;
 import org.kie.workbench.common.dmn.client.graph.DMNGraphUtils;
 import org.kie.workbench.common.dmn.client.session.DMNSession;
@@ -36,6 +39,10 @@ import org.uberfire.mvp.Command;
 
 public class ExpressionEditor implements ExpressionEditorView.Presenter {
 
+    private DMNDiagramsSession dmnDiagramsSession;
+
+    private DRDNameChanger drdNameChanger;
+
     private ExpressionEditorView view;
 
     private Optional<Command> exitCommand = Optional.empty();
@@ -48,20 +55,26 @@ public class ExpressionEditor implements ExpressionEditorView.Presenter {
 
     private DMNGraphUtils dmnGraphUtils;
 
-    // See DROOLS-3706. This returns the name of the DMN file's Definitions not the name of
-    // the DRG or DRD being displayed. At the point DROOLS-3706 was implemented the DMN
-    // Editor did not support DRGs so this name was chosen by default.
+    // When the current selection is the DRG, we return its name, otherwise the name of the selected DRD
     private final Supplier<String> returnToLinkTextSupplier = new Supplier<String>() {
         @Override
         public String get() {
-            return extractReturnToLinkFromDefinitions();
+            if (dmnDiagramsSession.isGlobalGraphSelected()) {
+                return extractReturnToLinkFromDefinitions();
+            }
+            drdNameChanger.hideDRDNameChanger();
+            return dmnDiagramsSession
+                    .getCurrentDMNDiagramElement()
+                    .map(DMNDiagramElement::getName)
+                    .orElse(new Name())
+                    .getValue();
         }
 
         private String extractReturnToLinkFromDefinitions() {
             if (Objects.isNull(dmnGraphUtils)) {
                 return "";
             }
-            final Definitions definitions = dmnGraphUtils.getDefinitions();
+            final Definitions definitions = dmnGraphUtils.getModelDefinitions();
             if (Objects.isNull(definitions)) {
                 return "";
             }
@@ -73,10 +86,14 @@ public class ExpressionEditor implements ExpressionEditorView.Presenter {
     @SuppressWarnings("unchecked")
     public ExpressionEditor(final ExpressionEditorView view,
                             final DecisionNavigatorPresenter decisionNavigator,
-                            final DMNGraphUtils dmnGraphUtils) {
+                            final DMNGraphUtils dmnGraphUtils,
+                            final DMNDiagramsSession dmnDiagramsSession,
+                            final DRDNameChanger drdNameChanger) {
         this.view = view;
         this.decisionNavigator = decisionNavigator;
         this.dmnGraphUtils = dmnGraphUtils;
+        this.dmnDiagramsSession = dmnDiagramsSession;
+        this.drdNameChanger = drdNameChanger;
 
         this.view.init(this);
     }
@@ -126,6 +143,9 @@ public class ExpressionEditor implements ExpressionEditorView.Presenter {
             toolbarStateHandler.ifPresent(ToolbarStateHandler::enterGraphView);
             command.execute();
             exitCommand = Optional.empty();
+            if (!dmnDiagramsSession.isGlobalGraphSelected()) {
+                drdNameChanger.showDRDNameChanger();
+            }
         });
     }
 
@@ -135,7 +155,7 @@ public class ExpressionEditor implements ExpressionEditorView.Presenter {
         if ((element instanceof Node)) {
             if (element.getContent() instanceof Definition) {
                 final Definition definition = (Definition) element.getContent();
-                final Optional<Definitions> definitions = Optional.ofNullable(dmnGraphUtils.getDefinitions());
+                final Optional<Definitions> definitions = Optional.ofNullable(dmnGraphUtils.getModelDefinitions());
                 definitions.ifPresent(d -> {
                     if (Objects.equals(d, definition.getDefinition())) {
                         view.setReturnToLinkText(returnToLinkTextSupplier.get());
@@ -144,17 +164,19 @@ public class ExpressionEditor implements ExpressionEditorView.Presenter {
                 hasExpression.ifPresent(e -> {
                     if (Objects.equals(e.asDMNModelInstrumentedBase(), definition.getDefinition())) {
                         view.setExpressionNameText(Optional.ofNullable((HasName) definition.getDefinition()));
+                        view.refresh();
                     }
                 });
             }
         }
     }
 
+    @Override
+    public boolean isActive() {
+        return getExitCommand().isPresent();
+    }
+
     Optional<Command> getExitCommand() {
         return exitCommand;
     }
-
-    public boolean isActive() {
-        return exitCommand.isPresent();
-    }
 }
