@@ -26,62 +26,67 @@ import javax.inject.Inject;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.kie.workbench.common.dmn.api.definition.HasExpression;
 import org.kie.workbench.common.dmn.api.definition.HasName;
-import org.kie.workbench.common.dmn.api.definition.v1_1.Context;
-import org.kie.workbench.common.dmn.api.definition.v1_1.ContextEntry;
-import org.kie.workbench.common.dmn.api.definition.v1_1.InformationItem;
-import org.kie.workbench.common.dmn.api.definition.v1_1.LiteralExpression;
+import org.kie.workbench.common.dmn.api.definition.model.Context;
+import org.kie.workbench.common.dmn.api.definition.model.ContextEntry;
+import org.kie.workbench.common.dmn.api.definition.model.Expression;
+import org.kie.workbench.common.dmn.api.definition.model.InformationItem;
 import org.kie.workbench.common.dmn.api.qualifiers.DMNEditor;
+import org.kie.workbench.common.dmn.client.commands.factory.DefaultCanvasCommandFactory;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.BaseEditorDefinition;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionEditorDefinitions;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionType;
+import org.kie.workbench.common.dmn.client.editors.types.ValueAndDataTypePopoverView;
 import org.kie.workbench.common.dmn.client.resources.i18n.DMNEditorConstants;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
-import org.kie.workbench.common.dmn.client.widgets.grid.controls.container.CellEditorControlsView;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
+import org.kie.workbench.common.dmn.client.widgets.grid.model.BaseUIModelMapper;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridData;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.ExpressionEditorChanged;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
-import org.kie.workbench.common.dmn.client.widgets.layer.DMNGridLayer;
-import org.kie.workbench.common.dmn.client.widgets.panel.DMNGridPanel;
+import org.kie.workbench.common.stunner.core.client.ReadOnlyProvider;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
-import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
+import org.kie.workbench.common.stunner.core.client.canvas.event.selection.DomainObjectSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
-import org.kie.workbench.common.stunner.core.client.session.Session;
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
+import org.kie.workbench.common.stunner.forms.client.event.RefreshFormPropertiesEvent;
+import org.uberfire.ext.wires.core.grids.client.model.GridData;
 
 @ApplicationScoped
 public class ContextEditorDefinition extends BaseEditorDefinition<Context, ContextGridData> {
 
     private Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier;
+    private ValueAndDataTypePopoverView.Presenter headerEditor;
 
     public ContextEditorDefinition() {
         //CDI proxy
     }
 
     @Inject
-    public ContextEditorDefinition(final @DMNEditor DMNGridPanel gridPanel,
-                                   final @DMNEditor DMNGridLayer gridLayer,
-                                   final DefinitionUtils definitionUtils,
+    public ContextEditorDefinition(final DefinitionUtils definitionUtils,
                                    final SessionManager sessionManager,
-                                   final @Session SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
-                                   final CanvasCommandFactory<AbstractCanvasHandler> canvasCommandFactory,
+                                   final SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
+                                   final @DMNEditor DefaultCanvasCommandFactory canvasCommandFactory,
                                    final Event<ExpressionEditorChanged> editorSelectedEvent,
-                                   final CellEditorControlsView.Presenter cellEditorControls,
+                                   final Event<RefreshFormPropertiesEvent> refreshFormPropertiesEvent,
+                                   final Event<DomainObjectSelectionEvent> domainObjectSelectionEvent,
                                    final ListSelectorView.Presenter listSelector,
                                    final TranslationService translationService,
-                                   final @DMNEditor Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier) {
-        super(gridPanel,
-              gridLayer,
-              definitionUtils,
+                                   final @DMNEditor Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier,
+                                   final ValueAndDataTypePopoverView.Presenter headerEditor,
+                                   final @DMNEditor ReadOnlyProvider readOnlyProvider) {
+        super(definitionUtils,
               sessionManager,
               sessionCommandManager,
               canvasCommandFactory,
               editorSelectedEvent,
-              cellEditorControls,
+              refreshFormPropertiesEvent,
+              domainObjectSelectionEvent,
               listSelector,
-              translationService);
+              translationService,
+              readOnlyProvider);
         this.expressionEditorDefinitionsSupplier = expressionEditorDefinitionsSupplier;
+        this.headerEditor = headerEditor;
     }
 
     @Override
@@ -101,6 +106,7 @@ public class ContextEditorDefinition extends BaseEditorDefinition<Context, Conte
 
     @Override
     public void enrich(final Optional<String> nodeUUID,
+                       final HasExpression hasExpression,
                        final Optional<Context> expression) {
         expression.ifPresent(context -> {
             final ContextEntry contextEntry = new ContextEntry();
@@ -111,51 +117,52 @@ public class ContextEditorDefinition extends BaseEditorDefinition<Context, Conte
 
             //Add (default) "result" entry
             final ContextEntry resultEntry = new ContextEntry();
-            final LiteralExpression literalExpression = new LiteralExpression();
-            resultEntry.setExpression(literalExpression);
             context.getContextEntry().add(resultEntry);
 
             //Setup parent relationships
             contextEntry.setParent(context);
             informationItem.setParent(contextEntry);
             resultEntry.setParent(context);
-            literalExpression.setParent(resultEntry);
         });
     }
 
     @Override
-    public Optional<BaseExpressionGrid> getEditor(final GridCellTuple parent,
-                                                  final Optional<String> nodeUUID,
-                                                  final HasExpression hasExpression,
-                                                  final Optional<Context> expression,
-                                                  final Optional<HasName> hasName,
-                                                  final int nesting) {
+    public Optional<BaseExpressionGrid<? extends Expression, ? extends GridData, ? extends BaseUIModelMapper>> getEditor(final GridCellTuple parent,
+                                                                                                                         final Optional<String> nodeUUID,
+                                                                                                                         final HasExpression hasExpression,
+                                                                                                                         final Optional<HasName> hasName,
+                                                                                                                         final boolean isOnlyVisualChangeAllowed,
+                                                                                                                         final int nesting) {
         return Optional.of(new ContextGrid(parent,
                                            nodeUUID,
                                            hasExpression,
-                                           expression,
                                            hasName,
-                                           gridPanel,
-                                           gridLayer,
-                                           makeGridData(expression),
+                                           getGridPanel(),
+                                           getGridLayer(),
+                                           makeGridData(() -> Optional.ofNullable((Context) hasExpression.getExpression())),
                                            definitionUtils,
                                            sessionManager,
                                            sessionCommandManager,
                                            canvasCommandFactory,
                                            editorSelectedEvent,
-                                           cellEditorControls,
+                                           refreshFormPropertiesEvent,
+                                           domainObjectSelectionEvent,
+                                           getCellEditorControls(),
                                            listSelector,
                                            translationService,
+                                           isOnlyVisualChangeAllowed,
                                            nesting,
-                                           expressionEditorDefinitionsSupplier));
+                                           expressionEditorDefinitionsSupplier,
+                                           headerEditor,
+                                           readOnlyProvider));
     }
 
     @Override
-    protected ContextGridData makeGridData(final Optional<Context> expression) {
+    protected ContextGridData makeGridData(final Supplier<Optional<Context>> expression) {
         return new ContextGridData(new DMNGridData(),
                                    sessionManager,
                                    sessionCommandManager,
                                    expression,
-                                   gridLayer::batch);
+                                   getGridLayer()::batch);
     }
 }
