@@ -18,8 +18,6 @@ package org.kie.workbench.common.dmn.client.widgets.grid.columns.factory;
 
 import java.util.function.Function;
 
-import com.google.gwt.event.dom.client.KeyDownEvent;
-import com.google.gwt.event.dom.client.MouseDownEvent;
 import org.gwtbootstrap3.client.ui.TextBox;
 import org.kie.workbench.common.dmn.client.widgets.grid.columns.factory.dom.TextBoxDOMElement;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
@@ -29,7 +27,6 @@ import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
 import org.kie.workbench.common.stunner.core.command.Command;
-import org.uberfire.ext.wires.core.grids.client.widget.context.GridBodyCellRenderContext;
 import org.uberfire.ext.wires.core.grids.client.widget.dom.single.impl.BaseSingletonDOMElementFactory;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.GridWidget;
 import org.uberfire.ext.wires.core.grids.client.widget.layer.GridLayer;
@@ -67,29 +64,20 @@ public class TextBoxSingletonDOMElementFactory extends BaseSingletonDOMElementFa
 
     @Override
     public TextBox createWidget() {
-        return new TextBox() {{
-            addKeyDownHandler(KeyDownEvent::stopPropagation);
-            addMouseDownHandler(MouseDownEvent::stopPropagation);
-        }};
+        return new TextBox();
     }
 
     @Override
-    public TextBoxDOMElement createDomElement(final GridLayer gridLayer,
-                                              final GridWidget gridWidget,
-                                              final GridBodyCellRenderContext context) {
-        this.widget = createWidget();
-        this.e = new TextBoxDOMElement(widget,
-                                       gridLayer,
-                                       gridWidget,
-                                       sessionManager,
-                                       sessionCommandManager,
-                                       hasNoValueCommand,
-                                       hasValueCommand);
-        widget.addBlurHandler((event) -> {
-            destroyResources();
-            gridPanel.setFocus(true);
-        });
-        return e;
+    protected TextBoxDOMElement createDomElementInternal(final TextBox widget,
+                                                         final GridLayer gridLayer,
+                                                         final GridWidget gridWidget) {
+        return new TextBoxDOMElement(widget,
+                                     gridLayer,
+                                     gridWidget,
+                                     sessionManager,
+                                     sessionCommandManager,
+                                     hasNoValueCommand,
+                                     hasValueCommand);
     }
 
     @Override
