@@ -22,17 +22,17 @@ import org.assertj.core.api.Assertions;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
-import org.kie.workbench.common.dmn.api.definition.v1_1.Binding;
-import org.kie.workbench.common.dmn.api.definition.v1_1.InformationItem;
-import org.kie.workbench.common.dmn.api.definition.v1_1.Invocation;
+import org.kie.workbench.common.dmn.api.definition.model.Binding;
+import org.kie.workbench.common.dmn.api.definition.model.InformationItem;
+import org.kie.workbench.common.dmn.api.definition.model.Invocation;
 import org.kie.workbench.common.dmn.api.property.dmn.Name;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionEditorDefinitions;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ExpressionEditorColumn;
+import org.kie.workbench.common.dmn.client.editors.expressions.types.context.InformationItemCell;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.context.NameColumn;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.invocation.InvocationDefaultValueUtilities;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.invocation.InvocationUIModelMapper;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
-import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridRow;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandResultBuilder;
 import org.kie.workbench.common.stunner.core.client.command.CanvasViolation;
@@ -44,7 +44,9 @@ import org.kie.workbench.common.stunner.core.rule.RuleViolation;
 import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
 import org.uberfire.ext.wires.core.grids.client.model.GridData;
+import org.uberfire.ext.wires.core.grids.client.model.GridRow;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridData;
+import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridRow;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.GridWidget;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.columns.RowNumberColumn;
 
@@ -98,7 +100,7 @@ public class AddParameterBindingCommandTest {
 
     private GridData uiModel;
 
-    private DMNGridRow uiModelRow;
+    private GridRow uiModelRow;
 
     private InvocationUIModelMapper uiModelMapper;
 
@@ -114,7 +116,7 @@ public class AddParameterBindingCommandTest {
         this.binding.setParameter(parameter);
 
         this.uiModel = new BaseGridData(false);
-        this.uiModelRow = new DMNGridRow();
+        this.uiModelRow = new BaseGridRow();
         this.uiModel.appendColumn(uiRowNumberColumn);
         this.uiModel.appendColumn(uiNameColumn);
         this.uiModel.appendColumn(uiExpressionEditorColumn);
@@ -122,6 +124,7 @@ public class AddParameterBindingCommandTest {
         this.uiModelMapper = new InvocationUIModelMapper(gridWidget,
                                                          () -> uiModel,
                                                          () -> Optional.of(invocation),
+                                                         () -> false,
                                                          () -> expressionEditorDefinitions,
                                                          listSelector,
                                                          0);
@@ -135,7 +138,9 @@ public class AddParameterBindingCommandTest {
         doReturn(Optional.empty()).when(expressionEditorDefinitions).getExpressionEditorDefinition(any(Optional.class));
     }
 
-    private void makeCommand(final int uiRowIndex, final Binding rowBindingEntry, final DMNGridRow uiGridRow) {
+    private void makeCommand(final int uiRowIndex,
+                             final Binding rowBindingEntry,
+                             final GridRow uiGridRow) {
         this.command = new AddParameterBindingCommand(invocation,
                                                       rowBindingEntry,
                                                       uiModel,
@@ -153,7 +158,8 @@ public class AddParameterBindingCommandTest {
         makeCommand(uiRowIndex, binding, uiModelRow);
     }
 
-    private void makeCommand(final int uiRowIndex, final DMNGridRow uiGridRow) {
+    private void makeCommand(final int uiRowIndex,
+                             final GridRow uiGridRow) {
         final Binding rowEntry = new Binding();
         final InformationItem parameter = new InformationItem();
         parameter.setName(new Name());
@@ -174,7 +180,7 @@ public class AddParameterBindingCommandTest {
         assertEquals(rowNumberValue,
                      uiModel.getCell(rowNumberIndex, ROW_NUMBER_COLUMN_INDEX).getValue().getValue());
         assertEquals(nameColumnValue,
-                     uiModel.getCell(rowNumberIndex, BINDING_PARAMETER_COLUMN_INDEX).getValue().getValue());
+                     ((InformationItemCell.HasNameAndDataTypeCell) uiModel.getCell(rowNumberIndex, BINDING_PARAMETER_COLUMN_INDEX).getValue().getValue()).getName().getValue());
         assertNull(uiModel.getCell(rowNumberIndex, BINDING_EXPRESSION_COLUMN_INDEX));
     }
 
@@ -381,7 +387,7 @@ public class AddParameterBindingCommandTest {
         assertEquals(1,
                      uiModel.getCell(0, ROW_NUMBER_COLUMN_INDEX).getValue().getValue());
         assertEquals(InvocationDefaultValueUtilities.PREFIX + "1",
-                     uiModel.getCell(0, BINDING_PARAMETER_COLUMN_INDEX).getValue().getValue());
+                     ((InformationItemCell.HasNameAndDataTypeCell) uiModel.getCell(0, BINDING_PARAMETER_COLUMN_INDEX).getValue().getValue()).getName().getValue());
         assertNull(uiModel.getCell(0, BINDING_EXPRESSION_COLUMN_INDEX));
 
         verify(canvasOperation).execute();
@@ -397,7 +403,7 @@ public class AddParameterBindingCommandTest {
                      firstEntryCanvasCommand.execute(handler));
 
         // second row
-        final DMNGridRow uiSecondModelRow = new DMNGridRow();
+        final GridRow uiSecondModelRow = new BaseGridRow();
         makeCommand(1, uiSecondModelRow);
         command.newGraphCommand(handler).execute(gce);
         final Command<AbstractCanvasHandler, CanvasViolation> secondEntryCanvasCommand = command.newCanvasCommand(handler);
@@ -405,7 +411,7 @@ public class AddParameterBindingCommandTest {
                      secondEntryCanvasCommand.execute(handler));
 
         // third row
-        final DMNGridRow uiThirdModelRow = new DMNGridRow();
+        final GridRow uiThirdModelRow = new BaseGridRow();
         makeCommand(0, uiThirdModelRow);
         command.newGraphCommand(handler).execute(gce);
         final Command<AbstractCanvasHandler, CanvasViolation> thirdEntryCanvasCommand = command.newCanvasCommand(handler);
