@@ -275,6 +275,11 @@ public class ContainerView extends Composite
         return translationService.format(Constants.ContainerView_StartContainerErrorMessage);
     }
 
+    @Override
+    public String getCanNotStopContainerMessage() {
+        return translationService.format(Constants.CanNot_Stop_Container);
+    }
+
     private String getConfirmRemovePopupMessage() {
         return translationService.format(Constants.ContainerView_ConfirmRemovePopupMessage);
     }
