@@ -34,6 +34,7 @@ import org.kie.server.controller.api.model.spec.ContainerSpec;
 import org.kie.server.controller.api.model.spec.ContainerSpecKey;
 import org.kie.server.controller.api.model.spec.ServerTemplate;
 import org.kie.server.controller.api.model.spec.ServerTemplateKey;
+import org.kie.server.controller.api.model.spec.ServerTemplateKeyList;
 import org.kie.workbench.common.screens.server.management.client.container.ContainerPresenter;
 import org.kie.workbench.common.screens.server.management.client.container.empty.ServerContainerEmptyPresenter;
 import org.kie.workbench.common.screens.server.management.client.empty.ServerEmptyPresenter;
@@ -197,7 +198,7 @@ public class ServerManagementBrowserPresenterTest {
     public void testOnOpen() {
         final ServerTemplateKey serverTemplateKey = new ServerTemplateKey( "ServerTemplateKeyId", "ServerTemplateKeyName" );
         final List<ServerTemplateKey> serverTemplateKeys = Collections.singletonList( serverTemplateKey );
-        when( specManagementService.listServerTemplateKeys() ).thenReturn( serverTemplateKeys );
+        when( specManagementService.listServerTemplateKeys() ).thenReturn( new ServerTemplateKeyList(serverTemplateKeys) );
 
         presenter.onOpen();
 
@@ -222,7 +223,7 @@ public class ServerManagementBrowserPresenterTest {
     public void testOnServerDeleted() {
         final ServerTemplateKey serverTemplateKey = new ServerTemplateKey( "ServerTemplateKeyId", "ServerTemplateKeyName" );
         final List<ServerTemplateKey> serverTemplateKeys = Collections.singletonList( serverTemplateKey );
-        when( specManagementService.listServerTemplateKeys() ).thenReturn( serverTemplateKeys );
+        when( specManagementService.listServerTemplateKeys() ).thenReturn( new ServerTemplateKeyList(serverTemplateKeys) );
 
         presenter.onServerDeleted( new ServerTemplateDeleted() );
 
@@ -234,19 +235,25 @@ public class ServerManagementBrowserPresenterTest {
 
     @Test
     public void testOnServerTemplateUpdated() {
+        final ServerInstanceKey serverInstanceKey = new ServerInstanceKey( "serverInstanceKeyId", "serverName", "serverInstanceId", "url" );
         final ServerTemplate serverTemplate = new ServerTemplate( "ServerTemplateId", "ServerTemplateName" );
+        serverTemplate.addServerInstance( serverInstanceKey );
+        when( serverTemplatePresenter.getCurrentServerTemplate() ).thenReturn( serverTemplate );
+        final ServerTemplateKey serverTemplateKey = new ServerTemplateKey( "ServerTemplateKeyId", "ServerTemplateKeyName" );
+        final List<ServerTemplateKey> serverTemplateKeys = Collections.singletonList( serverTemplateKey );
+        when( specManagementService.listServerTemplateKeys() ).thenReturn( new ServerTemplateKeyList(serverTemplateKeys) );
 
         presenter.onServerTemplateUpdated( new ServerTemplateUpdated( serverTemplate ) );
 
         final ArgumentCaptor<Collection> serverTemplateKeysCaptor = ArgumentCaptor.forClass( Collection.class );
-        verify( navigationPresenter ).setup( eq( serverTemplate ), serverTemplateKeysCaptor.capture() );
-        final Collection<ServerTemplateKey> serverTemplateKeys = serverTemplateKeysCaptor.getValue();
-        assertEquals( 1, serverTemplateKeys.size() );
-        assertTrue( serverTemplateKeys.contains( serverTemplate ) );
+        verify( navigationPresenter ).setup( eq( serverTemplateKey ), serverTemplateKeysCaptor.capture() );
+        final Collection<ServerTemplateKey> serverTemplateKeysValue = serverTemplateKeysCaptor.getValue();
+        assertEquals( 1, serverTemplateKeysValue.size() );
+        assertTrue( serverTemplateKeysValue.contains( serverTemplateKey ) );
 
         final ArgumentCaptor<ServerTemplateSelected> templateSelectedCaptor = ArgumentCaptor.forClass( ServerTemplateSelected.class );
         verify( serverTemplateSelectedEvent ).fire( templateSelectedCaptor.capture() );
-        assertEquals( serverTemplate, templateSelectedCaptor.getValue().getServerTemplateKey() );
+        assertEquals( serverTemplateKey, templateSelectedCaptor.getValue().getServerTemplateKey() );
     }
 
     @Test
@@ -257,7 +264,7 @@ public class ServerManagementBrowserPresenterTest {
         when( serverTemplatePresenter.getCurrentServerTemplate() ).thenReturn( serverTemplate );
         final ServerTemplateKey serverTemplateKey = new ServerTemplateKey( "ServerTemplateKeyId", "ServerTemplateKeyName" );
         final List<ServerTemplateKey> serverTemplateKeys = Collections.singletonList( serverTemplateKey );
-        when( specManagementService.listServerTemplateKeys() ).thenReturn( serverTemplateKeys );
+        when( specManagementService.listServerTemplateKeys() ).thenReturn( new ServerTemplateKeyList(serverTemplateKeys) );
 
         presenter.onDelete( new ServerInstanceDeleted( serverInstanceKey.getServerInstanceId() ) );
 
