@@ -45,6 +45,7 @@ import org.kie.workbench.common.screens.server.management.client.util.State;
 import org.kie.workbench.common.screens.server.management.model.ContainerRuntimeOperation;
 import org.kie.workbench.common.screens.server.management.model.ContainerSpecData;
 import org.kie.workbench.common.screens.server.management.model.ContainerUpdateEvent;
+import org.kie.workbench.common.screens.server.management.service.ContainerService;
 import org.kie.workbench.common.screens.server.management.service.RuntimeManagementService;
 import org.kie.workbench.common.screens.server.management.service.SpecManagementService;
 import org.mockito.ArgumentCaptor;
@@ -82,6 +83,8 @@ public class ContainerPresenterTest {
 
     Caller<SpecManagementService> specManagementServiceCaller;
 
+    Caller<ContainerService> containerServiceCaller;
+
     @Mock
     SpecManagementService specManagementService;
 
@@ -106,6 +109,9 @@ public class ContainerPresenterTest {
     @Mock
     ContainerProcessConfigPresenter containerProcessConfigPresenter;
 
+    @Mock
+    ContainerService containerService;
+
     ContainerPresenter presenter;
 
     ReleaseId releaseId;
@@ -122,6 +128,7 @@ public class ContainerPresenterTest {
     public void init() {
         runtimeManagementServiceCaller = new CallerMock<RuntimeManagementService>(runtimeManagementService);
         specManagementServiceCaller = new CallerMock<SpecManagementService>(specManagementService);
+        containerServiceCaller = new CallerMock<ContainerService>(containerService) ;
         doNothing().when(serverTemplateSelectedEvent).fire(any(ServerTemplateSelected.class));
         doNothing().when(notification).fire(any(NotificationEvent.class));
         when(containerStatusEmptyPresenter.getView()).thenReturn(containerStatusEmptyPresenterView);
@@ -136,7 +143,8 @@ public class ContainerPresenterTest {
                 runtimeManagementServiceCaller,
                 specManagementServiceCaller,
                 serverTemplateSelectedEvent,
-                notification));
+                notification,
+                containerServiceCaller));
 
         releaseId = new ReleaseId("org.kie",
                                   "container",
@@ -196,7 +204,6 @@ public class ContainerPresenterTest {
     @Test
     public void testStartContainer() {
         presenter.loadContainers(containerSpecData);
-
         presenter.startContainer();
 
         verify(view).setContainerStartState(State.ENABLED);
@@ -221,6 +228,7 @@ public class ContainerPresenterTest {
 
     @Test
     public void testStopContainer() {
+        when(containerService.isRunningContainer(any())).thenReturn(false);
         presenter.loadContainers(containerSpecData);
 
         presenter.stopContainer();
@@ -242,8 +250,15 @@ public class ContainerPresenterTest {
         verify(view).setContainerStartState(State.ENABLED);
         verify(view).setContainerStopState(State.DISABLED);
         verify(view).disableRemoveButton();
+
+        when(containerService.isRunningContainer(any())).thenReturn(true);
+        final String canNotStopMessage = "can not stop";
+        when(view.getCanNotStopContainerMessage()).thenReturn(canNotStopMessage);
+        presenter.stopContainer();
+        verify(notification).fire(new NotificationEvent(canNotStopMessage, NotificationEvent.NotificationType.WARNING));
+        verify(specManagementService, times(2)).stopContainer(any());
     }
-    
+
     @Test
     public void testDeactivateContainerFromStopedState() {
         presenter.loadContainers(containerSpecData);
