@@ -1,5 +1,7 @@
 package org.kie.workbench.common.services.backend.healthcheck;
 
+import java.net.URI;
+
 import javax.enterprise.context.ApplicationScoped;
 import javax.inject.Inject;
 import javax.inject.Named;
@@ -7,7 +9,6 @@ import javax.inject.Named;
 import org.uberfire.io.IOService;
 import org.uberfire.java.nio.file.FileSystem;
 
-import static org.guvnor.structure.server.config.ConfigType.GLOBAL;
 import static org.kie.workbench.common.services.backend.healthcheck.ServiceStatus.HEALTHY;
 import static org.kie.workbench.common.services.backend.healthcheck.ServiceStatus.INCONCLUSIVE;
 import static org.kie.workbench.common.services.backend.healthcheck.ServiceStatus.UNHEALTHY;
@@ -17,27 +18,36 @@ public class IoServiceCheck implements ServiceCheck {
 
     private final IOService ioService;
 
-    private final FileSystem fileSystem;
-
     @Inject
-    public IoServiceCheck(final @Named("configIO") IOService ioService,
-                          final @Named("systemFS") FileSystem fileSystem) {
+    public IoServiceCheck(final @Named("configIO") IOService ioService) {
 
         this.ioService = ioService;
-        this.fileSystem = fileSystem;
     }
 
     @Override
     public ServiceStatus getStatus() {
         try {
-            return globalDirExists() ? HEALTHY : UNHEALTHY;
+            return systemFsExists() ? HEALTHY : UNHEALTHY;
         } catch (final Exception e) {
             return INCONCLUSIVE;
         }
     }
 
-    boolean globalDirExists() {
-        return ioService.exists(fileSystem.getPath(GLOBAL.getDir()));
+    boolean systemFsExists() {
+        try {
+            final FileSystem fileSystem = getFileSystem();
+            if (fileSystem == null) {
+                return false;
+            }
+
+            return fileSystem.isOpen();
+        } catch (final Exception e) {
+            return false;
+        }
+    }
+
+    FileSystem getFileSystem() {
+        return ioService.getFileSystem(URI.create("default://system/system"));
     }
 
     @Override
