@@ -21,9 +21,9 @@ import java.util.Objects;
 import javax.validation.Valid;
 
 import org.jboss.errai.common.client.api.annotations.MapsTo;
-import org.jboss.errai.common.client.api.annotations.NonPortable;
 import org.jboss.errai.common.client.api.annotations.Portable;
 import org.jboss.errai.databinding.client.api.Bindable;
+import org.kie.workbench.common.forms.adf.definitions.annotations.FieldParam;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormDefinition;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormField;
 import org.kie.workbench.common.forms.adf.definitions.settings.FieldPolicy;
@@ -35,42 +35,41 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.event.message.M
 import org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.BPMNGeneralSet;
 import org.kie.workbench.common.stunner.core.definition.annotation.Definition;
-import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
+import org.kie.workbench.common.stunner.core.definition.annotation.Property;
 import org.kie.workbench.common.stunner.core.definition.annotation.morph.Morph;
-import org.kie.workbench.common.stunner.core.definition.builder.Builder;
-import org.kie.workbench.common.stunner.core.factory.graph.NodeFactory;
 import org.kie.workbench.common.stunner.core.util.HashUtil;
 
+import static org.kie.workbench.common.forms.adf.engine.shared.formGeneration.processing.fields.fieldInitializers.nestedForms.SubFormFieldInitializer.COLLAPSIBLE_CONTAINER;
+import static org.kie.workbench.common.forms.adf.engine.shared.formGeneration.processing.fields.fieldInitializers.nestedForms.SubFormFieldInitializer.FIELD_CONTAINER_PARAM;
+
 @Portable
 @Bindable
-@Definition(graphFactory = NodeFactory.class, builder = IntermediateMessageEventThrowing.IntermediateMessageEventThrowingBuilder.class)
+@Definition
 @Morph(base = BaseThrowingIntermediateEvent.class)
 @FormDefinition(
         startElement = "general",
-        policy = FieldPolicy.ONLY_MARKED
+        policy = FieldPolicy.ONLY_MARKED,
+        defaultFieldSettings = {@FieldParam(name = FIELD_CONTAINER_PARAM, value = COLLAPSIBLE_CONTAINER)}
 )
 public class IntermediateMessageEventThrowing extends BaseThrowingIntermediateEvent {
 
-    @PropertySet
+    @Property
     @FormField(afterElement = "general")
     @Valid
-    protected MessageEventExecutionSet executionSet;
+    private MessageEventExecutionSet executionSet;
 
-    @NonPortable
-    public static class IntermediateMessageEventThrowingBuilder implements Builder<IntermediateMessageEventThrowing> {
-
-        @Override
-        public IntermediateMessageEventThrowing build() {
-            return new IntermediateMessageEventThrowing(new BPMNGeneralSet(""),
-                                                        new DataIOSet(),
-                                                        new BackgroundSet(),
-                                                        new FontSet(),
-                                                        new CircleDimensionSet(new Radius()),
-                                                        new MessageEventExecutionSet());
-        }
-    }
+    @Property
+    @FormField(afterElement = "executionSet")
+    @Valid
+    private DataIOSet dataIOSet;
 
     public IntermediateMessageEventThrowing() {
+        this(new BPMNGeneralSet(""),
+             new DataIOSet(),
+             new BackgroundSet(),
+             new FontSet(),
+             new CircleDimensionSet(new Radius()),
+             new MessageEventExecutionSet());
     }
 
     public IntermediateMessageEventThrowing(final @MapsTo("general") BPMNGeneralSet general,
@@ -80,10 +79,10 @@ public class IntermediateMessageEventThrowing extends BaseThrowingIntermediateEv
                                             final @MapsTo("dimensionsSet") CircleDimensionSet dimensionsSet,
                                             final @MapsTo("executionSet") MessageEventExecutionSet executionSet) {
         super(general,
-              dataIOSet,
               backgroundSet,
               fontSet,
               dimensionsSet);
+        this.dataIOSet = dataIOSet;
         this.executionSet = executionSet;
     }
 
@@ -111,16 +110,27 @@ public class IntermediateMessageEventThrowing extends BaseThrowingIntermediateEv
         this.executionSet = executionSet;
     }
 
+    public DataIOSet getDataIOSet() {
+        return dataIOSet;
+    }
+
+    public void setDataIOSet(DataIOSet dataIOSet) {
+        this.dataIOSet = dataIOSet;
+    }
+
     @Override
     public int hashCode() {
         return HashUtil.combineHashCodes(super.hashCode(),
-                                         executionSet.hashCode(),
-                                         dataIOSet.hashCode(),
-                                         labels.hashCode());
+                                         Objects.hashCode(executionSet),
+                                         Objects.hashCode(dataIOSet),
+                                         Objects.hashCode(labels));
     }
 
     @Override
     public boolean equals(Object o) {
+        if (this == o) {
+            return true;
+        }
         if (o instanceof IntermediateMessageEventThrowing) {
             IntermediateMessageEventThrowing other = (IntermediateMessageEventThrowing) o;
             return super.equals(other) &&
