@@ -18,9 +18,13 @@ package org.kie.workbench.common.stunner.bpmn.backend.converters.tostunner.gatew
 
 import org.eclipse.bpmn2.EventBasedGateway;
 import org.eclipse.bpmn2.Gateway;
+import org.kie.workbench.common.stunner.bpmn.backend.converters.BPMNElementDecorators;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.Match;
+import org.kie.workbench.common.stunner.bpmn.backend.converters.Result;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.TypedFactoryManager;
+import org.kie.workbench.common.stunner.bpmn.backend.converters.tostunner.AbstractConverter;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.tostunner.BpmnNode;
+import org.kie.workbench.common.stunner.bpmn.backend.converters.tostunner.NodeConverter;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.tostunner.properties.GatewayPropertyReader;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.tostunner.properties.PropertyReaderFactory;
 import org.kie.workbench.common.stunner.bpmn.definition.EventGateway;
@@ -35,27 +39,35 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.general.Name;
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
+import org.kie.workbench.common.stunner.core.marshaller.MarshallingRequest.Mode;
 
-public class GatewayConverter {
+public class GatewayConverter extends AbstractConverter implements NodeConverter<Gateway> {
 
     private final TypedFactoryManager factoryManager;
     private final PropertyReaderFactory propertyReaderFactory;
 
-    public GatewayConverter(TypedFactoryManager factoryManager, PropertyReaderFactory propertyReaderFactory) {
+    public GatewayConverter(TypedFactoryManager factoryManager, PropertyReaderFactory propertyReaderFactory,
+                            Mode mode) {
+        super(mode);
         this.factoryManager = factoryManager;
         this.propertyReaderFactory = propertyReaderFactory;
     }
 
-    public BpmnNode convert(org.eclipse.bpmn2.Gateway gateway) {
-        return Match.of(org.eclipse.bpmn2.Gateway.class, BpmnNode.class)
+    public Result<BpmnNode> convert(org.eclipse.bpmn2.Gateway gateway) {
+        return Match.of(org.eclipse.bpmn2.Gateway.class, Result.class)
                 .when(org.eclipse.bpmn2.ParallelGateway.class, this::parallelGateway)
                 .when(org.eclipse.bpmn2.ExclusiveGateway.class, this::exclusiveGateway)
                 .when(org.eclipse.bpmn2.InclusiveGateway.class, this::inclusiveGateway)
                 .when(org.eclipse.bpmn2.EventBasedGateway.class, this::eventGateway)
-                .apply(gateway).value();
+                .defaultValue(Result.ignored("Gateway not found"))
+                .inputDecorator(BPMNElementDecorators.flowElementDecorator())
+                .outputDecorator(BPMNElementDecorators.resultBpmnDecorator())
+                .mode(getMode())
+                .apply(gateway)
+                .value();
     }
 
-    private BpmnNode inclusiveGateway(Gateway gateway) {
+    private Result<BpmnNode> inclusiveGateway(Gateway gateway) {
         Node<View<InclusiveGateway>, Edge> node = factoryManager.newNode(gateway.getId(), InclusiveGateway.class);
 
         InclusiveGateway definition = node.getContent().getDefinition();
@@ -76,10 +88,10 @@ public class GatewayConverter {
         definition.setFontSet(p.getFontSet());
         definition.setBackgroundSet(p.getBackgroundSet());
 
-        return BpmnNode.of(node, p);
+        return Result.success(BpmnNode.of(node, p));
     }
 
-    private BpmnNode exclusiveGateway(Gateway gateway) {
+    private Result<BpmnNode> exclusiveGateway(Gateway gateway) {
         Node<View<ExclusiveGateway>, Edge> node = factoryManager.newNode(gateway.getId(), ExclusiveGateway.class);
 
         ExclusiveGateway definition = node.getContent().getDefinition();
@@ -100,10 +112,10 @@ public class GatewayConverter {
         definition.setFontSet(p.getFontSet());
         definition.setBackgroundSet(p.getBackgroundSet());
 
-        return BpmnNode.of(node, p);
+        return Result.success(BpmnNode.of(node, p));
     }
 
-    private BpmnNode parallelGateway(Gateway gateway) {
+    private Result<BpmnNode> parallelGateway(Gateway gateway) {
         Node<View<ParallelGateway>, Edge> node = factoryManager.newNode(gateway.getId(), ParallelGateway.class);
         GatewayPropertyReader p = propertyReaderFactory.of(gateway);
 
@@ -119,10 +131,10 @@ public class GatewayConverter {
         definition.setFontSet(p.getFontSet());
         definition.setBackgroundSet(p.getBackgroundSet());
 
-        return BpmnNode.of(node, p);
+        return Result.success(BpmnNode.of(node, p));
     }
 
-    private BpmnNode eventGateway(EventBasedGateway eventGateway) {
+    private Result<BpmnNode> eventGateway(EventBasedGateway eventGateway) {
         Node<View<EventGateway>, Edge> node = factoryManager.newNode(eventGateway.getId(), EventGateway.class);
         GatewayPropertyReader p = propertyReaderFactory.of(eventGateway);
 
@@ -138,6 +150,6 @@ public class GatewayConverter {
         definition.setFontSet(p.getFontSet());
         definition.setBackgroundSet(p.getBackgroundSet());
 
-        return BpmnNode.of(node, p);
+        return Result.success(BpmnNode.of(node, p));
     }
 }
