@@ -16,14 +16,16 @@
 
 package org.kie.workbench.common.stunner.bpmn.client.documentation;
 
+import java.util.Arrays;
 import java.util.Collection;
 import java.util.Comparator;
 import java.util.List;
 import java.util.Map;
 import java.util.Objects;
 import java.util.Optional;
-import java.util.Set;
 import java.util.function.Function;
+import java.util.logging.Level;
+import java.util.logging.Logger;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
 import java.util.stream.StreamSupport;
@@ -109,6 +111,7 @@ import org.kie.workbench.common.stunner.core.client.i18n.ClientTranslationServic
 import org.kie.workbench.common.stunner.core.client.session.ClientSession;
 import org.kie.workbench.common.stunner.core.client.shape.ImageStripGlyph;
 import org.kie.workbench.common.stunner.core.client.util.js.JsConverter;
+import org.kie.workbench.common.stunner.core.definition.adapter.DefinitionAdapter;
 import org.kie.workbench.common.stunner.core.definition.adapter.DefinitionId;
 import org.kie.workbench.common.stunner.core.definition.adapter.PropertyAdapter;
 import org.kie.workbench.common.stunner.core.definition.adapter.binding.BindableAdapterUtils;
@@ -125,6 +128,8 @@ import org.uberfire.ext.editor.commons.client.template.mustache.ClientMustacheTe
 @Dependent
 public class ClientBPMNDocumentationService implements BPMNDocumentationService {
 
+    private static Logger LOGGER = Logger.getLogger(ClientBPMNDocumentationService.class.getName());
+
     private static final Map<String, Boolean> ignoredPropertiesIds = buildIgnoredPropertiesIds();
     public static final int ICON_HEIGHT = 20;
     public static final int ICON_WIDTH = 20;
@@ -309,6 +314,7 @@ public class ClientBPMNDocumentationService implements BPMNDocumentationService
         return ProcessVariablesTotal.create(variables.size(), variables.size(), JsConverter.fromEntries(variables));
     }
 
+    @SuppressWarnings("all")
     private ElementDetails getElementsDetails(final Graph<?, Node> graph) {
         final List<ElementTotal> elementsTotals = StreamSupport.stream(graph.nodes().spliterator(), false)
                 .map(Node::getContent)
@@ -316,12 +322,8 @@ public class ClientBPMNDocumentationService implements BPMNDocumentationService
                 .map(c -> (Definition) c)
                 .map(Definition::getDefinition)
                 .filter(e -> !(e instanceof BPMNDiagram))
-                .map(def -> Element.create(getElementName(def),
-                                           getElementCategory(def),
-                                           getElementTitle(def),
-                                           getDefinitionIcon(def),
-                                           getElementProperties(def))
-                )
+                .map(this::processElement)
+                .filter(Objects::nonNull)
                 .sorted(Comparator.comparing(Element::getTitle))
                 .collect(Collectors.groupingBy(Element::getType))
                 .entrySet()
@@ -335,11 +337,25 @@ public class ClientBPMNDocumentationService implements BPMNDocumentationService
         return ElementDetails.create(elementsTotals);
     }
 
+    private Element processElement(Object def) {
+        String name = getElementName(def);
+        try {
+            return Element.create(name,
+                                  getElementCategory(def),
+                                  getElementTitle(def),
+                                  getDefinitionIcon(def),
+                                  getElementProperties(def));
+        } catch (Exception e) {
+            LOGGER.log(Level.SEVERE, "Error processing documentation properties for [" + name + "]", e);
+            return null;
+        }
+    }
+
     private String getElementTitle(Object def) {
         final DefinitionId definitionId = definitionManager.adapters().forDefinition().getId(def);
         return Optional.ofNullable(definitionId)
                 .map(DefinitionId::value)
-                .map(id -> definitionUtils.getTitle(id))
+                .map(definitionUtils::getTitle)
                 .orElse("");
     }
 
@@ -386,9 +402,12 @@ public class ClientBPMNDocumentationService implements BPMNDocumentationService
     }
 
     private Map<String, String> getElementProperties(Object definition) {
+        final DefinitionAdapter<Object> definitionAdapter = definitionManager.adapters().registry().getDefinitionAdapter(definition.getClass());
         final PropertyAdapter<Object, Object> propertyAdapter = definitionManager.adapters().forProperty();
-        final Set<?> properties = definitionManager.adapters().forDefinition().getProperties(definition);
-        return properties.stream()
+        return Arrays.stream(definitionAdapter.getPropertyFields(definition))
+                .map(field -> definitionAdapter.getProperty(definition, field))
+                .filter(Optional::isPresent)
+                .map(Optional::get)
                 .filter(prop -> !ignoredPropertiesIds.containsKey(propertyAdapter.getId(prop)))
                 .filter(prop -> StringUtils.nonEmpty(propertyAdapter.getCaption(prop)))
                 .filter(prop -> Objects.nonNull(propertyAdapter.getValue(prop)))
